@@ -2,6 +2,7 @@ from sqlalchemy import (
     Column,
     Integer,
     Unicode,
+    UnicodeText
     )
 
 from . import DBSession, Base
@@ -10,7 +11,7 @@ class Post(Base):
     __tablename__ = 'posts'
     id = Column(Integer, primary_key=True)
     title = Column(Unicode(200), unique=True)
-    content = Column(Text)
+    content = Column(UnicodeText)
 
     def __init__(self, title, content):
         self.title = title
